package com.dsic.gj_erp.service.sy.impl;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dsic.gj_erp.bean.sy.SyDictItem;
import com.dsic.gj_erp.mapper.SyDictItemMapper;
import com.dsic.gj_erp.service.sy.SyDictItemService;
import com.dsic.gj_erp.util.CacheConstant;
import com.dsic.gj_erp.util.ConditionSelect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author xhj
 * @since 2021-03-16
 */
@Service
public class SyDictItemServiceImpl extends ServiceImpl<SyDictItemMapper, SyDictItem> implements SyDictItemService {

   @Autowired
   SyDictItemMapper syDictItemMapper;


    /**
     * 根据表编码转换
     * @param table
     * @param text
     * @param code
     * @param key
     * @return
     */
    @Cacheable(value = CacheConstant.SYS_DICT_TABLE_CACHE,unless="#result == null")
    @Override
    public String translateDictFromTable(String table, String text, String code, String key) {
        log.debug("无缓存dictTable的时候调用这里！1");
        System.out.println("无缓存dictCache的时候调用这里！1");
        return syDictItemMapper.queryTableDictTextByKey(table, text, code, key);
    }

    /**
     * 编码转换
     * @param code
     * @param key
     * @return
     */
    @Cacheable(value = CacheConstant.SYS_DICT_CACHE,key = "#code+':'+#key", unless="#result == null")
    @Override
    public String translateDict(String code, String key) {
        log.debug("无缓存dictTable的时候调用这里！2");
        System.out.println("无缓存dictCache的时候调用这里！2");
        return syDictItemMapper.queryDictTextByKey(code, key);

    }

    /**
     * 多条件编码转换
     * @param table
     * @param text
     * @param code
     * @param key
     * @param code1
     * @param key1
     * @return
     */
    @Cacheable(value = CacheConstant.SYS_DICT_TABLE_BY_KEYS_CACHE)
    @Override
    public String translateDictFromTableByKey(String table, String text, String code, String key,String code1, String key1) {
        log.debug("无缓存dictTable的时候调用这里！3");
        System.out.println("无缓存dictCache的时候调用这里！3");
        return syDictItemMapper.queryTableDictTextByKeySys(table, text, code, key,code1, key1);

    }

    /**
     * 通过编码获取同编码的值
     * @param syDictItem
     * @return
     */
    @Override
    public List<SyDictItem> getByCode(SyDictItem syDictItem) {
        QueryWrapper<SyDictItem> queryWrapper = new QueryWrapper<>();
        ConditionSelect<SyDictItem> conditionSelect = new ConditionSelect<>(syDictItem, queryWrapper, syDictItemMapper);
        return conditionSelect.getResult();
    }


    @Override
    public List<Map<String, Object>> getCodeByString(String code) {
        QueryWrapper<SyDictItem> qw = new QueryWrapper<>();
        qw.select("item_value as label","item_code as value");
        qw.eq("dict_code",code);

//        this.list(qw);
        List<Map<String, Object>> maps = syDictItemMapper.selectMaps(qw);
        return maps;
    }

    @Override
    public Map<String, SyDictItem> getCodeToMap(String dictCode) {
        return baseMapper.getCodeToMap(dictCode);
    }
}
